
;*********************************************************************************
;* error.s:
;*	Error messages
;*********************************************************************************

;********************************************************************************
;* This file is part of gibl:							*
;*	Gordons Interactive Basic Language                                      *
;********************************************************************************
;*    A Tiny Basic for the 6502 inspired by the NIBL Tiny Basic interpreter;	*
;*    "National Industrial Basic Language" originally for the INS8060 SC/MP	*
;*    system.									*
;*										*
;*    gibl is distributed under a "Source Available" license.			*
;*	It is NOT Open source and must not be treated as such.			*
;*										*
;*    See the file LICENSE for details.						*
;*										*
;*    gibl is Copyright (c) 2023 by Gordon Henderson				*
;********************************************************************************

	.macpack	generic

	.include	"data.h"
	.include	"system.h"
	.include	"ilMacros.h"
	.include	"flow.h"
	.include	"print.h"

	.include	"error.h"

;********************************************************************************
;* errorMsgs:
;********************************************************************************

errorMsgs:
;	strTop	" ERROR"	;   1 - note leading space
	strTop	" *"		;   1 - saving space
	strTop	"AREA"		;   2
	strTop	"STMT"		;   3
	strTop	"CHAR"		;   4
	strTop	"SNTX"		;   5
	strTop	"VALU"		;   6
	strTop	"END"		;   7
	strTop	"NOGO"		;   8
	strTop	"RTRN"		;   9
	strTop	"NEST"		;  10
	strTop	"NEXT"		;  11
	strTop	"FOR"		;  12
	strTop	"DIV0"		;  13
	strTop	"BRK"		;  14
	strTop	"UNTL"		;  15


;********************************************************************************
;* Error routine - first entry point is for syntax error.
;*	else enter at ERR1 with code in A
;*	Note: Error numbers are 1 through 15.
;********************************************************************************

syntaxErr:
	lda	#eSNTX

ERR1:	sta	num
	sta	eNum
	jsr	newLine

; Search the messages

	ldx	#0
next0:	dec	num
	beq	qqMsg		; Print it

; Scan to the next one

:	lda	errorMsgs,x
	bmi	next1
	inx
	bne	:-
next1:	inx			; Skip over the last char of the last message
	bne	next0

; Print

qqMsg:	lda	errorMsgs,x
	bmi	done
	jsr	putChar
	inx
	bne	qqMsg
done:
	and	#$7F		; Strip top bit on last character
	jsr	putChar

; Was it a break message?

	lda	eNum
	cmp	#eBRK
	beq	qq3		; Not really an error...

; Print ' ERROR'
;	XX Might take up less space to just call putStr ...

	jsr	putStr
	.asciiz	" ERROR"
;	ldx	#0
;:	lda	errorMsgs,x
;	bmi	:+
;	jsr	putChar
;	inx
;	bne	:-
;:	and	#$7F
;	jsr	putChar


; Test run/immediate mode

qq3:	lda	runMod
	bne	:+
	jmp	progFin		; If immediate mode
:	jsr	putStr
	.asciiz	" AT "

	lda	loLine
	sta	lo
	lda	hiLine
	sta	hi
	jsr	pDec

; Jump to progFin to tidy up

	jmp	progFin
